@@ -1,9 +1,12 @@
 ;(function(){
   var map = {
-  "css": [],
+  "css": [
+    "@zoom/client-scheduler/static/css/chunk-vendors.59e38391.css",
+    "@zoom/client-scheduler/static/css/index.884397a0.css"
+  ],
   "js": [
-    "@zoom/client-scheduler/static/js/chunk-vendors.f26129e8.js",
-    "@zoom/client-scheduler/static/js/index.bfe2ce09.js"
+    "@zoom/client-scheduler/static/js/chunk-vendors.cd16d45c.js",
+    "@zoom/client-scheduler/static/js/index.e01d66af.js"
   ]
 };
   var prefix = 'https://dev-integration.zoomdev.us/fe-static/';
